/****************************************************************************************
 * Copyright (c) 2009 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/
 
#ifndef LOVETRACKACTION_H
#define LOVETRACKACTION_H

#include "GlobalCollectionActions.h"

class LastFmService;

/**
A last.fm specific global collection action for loving a track.

	@author Nikolaj Hald Nielsen <nhn@kde.org>
*/
class LoveTrackAction : public GlobalCollectionTrackAction
{
    Q_OBJECT
public:
    LoveTrackAction( LastFmService * service );

private slots:
    void slotTriggered();

private:
    LastFmService * m_service;
};

#endif
